# KM3Astro

## About

KM3Astro is a collection astronomy utils, like coordinate transformations.

## Install

This is developed on python 3.6. Lower versions (especially py2)
might or might not work.

Install the dependencies

* numpy 
* pandas
* astropy

In your python env, do

  pip install git+http://git.km3net.de/moritz/km3astro.git

or just clone the git repository and install via ``pip install .``
